<?php

/**
 * @file
 * Hooks specific to the Entity type behaviors module.
 */

/**
 * Allows a user to preprocess behaviors.
 *
 * The hook does not take into account the entity type.
 * The hook does not take into account the bundle.
 * The hook does not take into account the behavior.
 *
 * @param array $variables
 *   An array containing the preprocess variables for an entity.
 * @param array $behaviors
 *   An array containing all the behaviors for that entity.
 */
function hook_entity_type_behaviors__preprocess_entity(array &$variables, array $behaviors) {
  $variables['behaviors'] = $behaviors;
}

/**
 * Allows a user to preprocess a specific behavior for all entity types.
 *
 * The hook does not take into account the entity type.
 * The hook does not take into account the bundle.
 *
 * @param array $variables
 *   An array containing the preprocess variables for an entity.
 * @param array $behavior
 *   The requested behavior config for that entity.
 */
function hook_entity_type_behaviors__preprocess__BEHAVIOR(array &$variables, array $behavior) {
  if (!empty($behavior['bg_color'])) {
    $variables['class'][] = 'test';
  }
}

/**
 * Allows a user to preprocess a specific behavior and an entity type.
 *
 * The hook does not take into account the bundle.
 *
 * @param array $variables
 *   An array containing the preprocess variables for an entity.
 * @param array $behavior
 *   The requested behavior config for that entity.
 */
function hook_entity_type_behaviors__preprocess__BEHAVIOR__ENTITY_TYPE(array &$variables, array $behavior) {
  if (!empty($behavior['bg_color'])) {
    $variables['class'][] = 'test-entity-type';
  }
}

/**
 * Allows a user to preprocess a specific behavior, an entity type and a bundle.
 *
 * @param array $variables
 *   An array containing the preprocess variables for an entity.
 * @param array $behavior
 *   The requested behavior config for that entity.
 */
function hook_entity_type_behaviors__preprocess__BEHAVIOR__ENTITY_TYPE__BUNDLE(array &$variables, array $behavior) {
  if (!empty($behavior['bg_color'])) {
    $variables['class'][] = 'test-entity-type-bundle';
  }
}
