<?php

namespace Drupal\entity_type_behaviors\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'comment' field type.
 *
 * @FieldType(
 *   id = "entity_type_behavior",
 *   label = @Translation("Entity Type Behavior"),
 *   description = @Translation("This field manages entity type behavior configuration."),
 *   default_widget = "entity_type_behavior_default",
 *   no_ui = TRUE
 * )
 */
class EntityTypeBehaviorItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    return [
      'behaviors' => [],
    ] + parent::defaultStorageSettings();
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(new TranslatableMarkup('Value'))
      ->setRequired(TRUE);

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    $schema = [
      'columns' => [
        'value' => [
          'type' => 'blob',
          'size' => 'big',
          'serialize' => TRUE,
        ],
      ],
    ];

    return $schema;
  }

  /**
   * Returns the unserialized value.
   *
   * @return mixed|null
   *   Returns the unserialized value.
   */
  public function getUnserializedValue() {
    $value = parent::getValue();

    if (!$value || !isset($value['value'])) {
      return NULL;
    }

    return unserialize($value['value']);
  }

}
